pub struct WireField {
pub name: String,
pub schema: WireSchema,
pub presence: FieldPresence,
}Expand description
One serialized field of a struct or struct variant.
Fields
name: StringThe serialized name, after rename and rename_all have been applied.
schema: WireSchemapresence: FieldPresenceImplementations
Sourceimpl WireField
impl WireField
Sourcepub fn new(
name: impl Into<String>,
schema: WireSchema,
presence: FieldPresence,
) -> Self
pub fn new( name: impl Into<String>, schema: WireSchema, presence: FieldPresence, ) -> Self
Declare one field.
Sourcepub fn required(name: impl Into<String>, schema: WireSchema) -> Self
pub fn required(name: impl Into<String>, schema: WireSchema) -> Self
Declare a field that is always written and always required.